/* =============================================================[ Display.cc ]=
 * Display.cc - display an interface
 * Copyright (C) 2002 Hubert Chan <hubert@uhoreg.ca>
 *
 * ----------------------------------------------------------------( License )-
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * ------------------------------------------------------------( Description )-
 *
 * This file handles the user interface display.  This is an abstract class.
 * Specific display types inherit from it.  It defines an interface for the
 * different components to notify it of changes.
 *
 * ------------------------------------------------------------------------- */

#include <alsaplayer/CorePlayer.h>

#include "Display.hh"

namespace {
  // wrappers around the core player notification
  void volume_changed(void *data, float vol)
  {
    Display *display = static_cast<Display*>(data);
    display->volumeChanged(vol);
  }
  void speed_changed(void *data, float speed)
  {
    Display *display = static_cast<Display*>(data);
    display->speedChanged(speed);
  }
  void pan_changed(void *data, float pan)
  {
    Display *display = static_cast<Display*>(data);
    display->panChanged(pan);
  }
  void position_notify(void *data, int frame)
  {
    Display *display = static_cast<Display*>(data);
    display->positionNotify(frame);
  }
  void stop_notify(void *data)
  {
    Display *display = static_cast<Display*>(data);
    display->playerStopped();
  }
  void start_notify(void *data)
  {
    Display *display = static_cast<Display*>(data);
    display->playerStarted();
  }
  coreplayer_notifier notifier = { NULL,
				   volume_changed,
				   speed_changed,
				   pan_changed,
				   position_notify,
				   start_notify,
				   stop_notify };
}

Display::Display(SessionData &_sd)
  : ModeSubscriber(_sd)
{ }

void Display::notifier_init()
{
  sessiondata.playlist->RegisterNotifier(&notifier, this);
}

Display::~Display()
{
  sessiondata.playlist->UnRegisterNotifier(&notifier);
}
