/* ===================================================[ PlaylistInterface.hh ]=
 * PlaylistInterface.hh - interface with the AlsaPlayer playlist
 * Copyright (C) 2002 Hubert Chan <hubert@uhoreg.ca>
 *
 * ----------------------------------------------------------------( License )-
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * ------------------------------------------------------------( Description )-
 *
 * This file fetches, keeps track of, and modifies the AlsaPlayer playlist.
 *
 * ------------------------------------------------------------------------- */

#include "debug.hh"

#include <string>
#include <sstream>

#include "PlaylistInterface.hh"

LIRC_PlaylistInterface::LIRC_PlaylistInterface(SessionData &_sessiondata)
  : sessiondata(_sessiondata)
{
  DEBUG3 << "creating PlaylistInterface\n";
  sessiondata.playlistInterface = this;
  if (sessiondata.display)
    sessiondata.display->playlistCleared();
  sessiondata.playlist->Register(this);
  DEBUG3 << "done creating PlaylistInterface\n";
}

LIRC_PlaylistInterface::~LIRC_PlaylistInterface()
{
  sessiondata.playlist->UnRegister(this);
}

void LIRC_PlaylistInterface::CbSetCurrent(unsigned pos)
{
  if (sessiondata.display)
    sessiondata.display->setCurrentSong(int(pos)-1);
}

void LIRC_PlaylistInterface::CbInsert(std::vector<PlayItem> &items, unsigned pos)
{
  DEBUG3 << "entering PlaylistInterface::CbInsert\n";
  playlist.insert(playlist.begin()+pos, items.begin(), items.end());

  if (sessiondata.display)
    sessiondata.display->songsInserted(int(pos)-1);
  DEBUG3 << "exiting PlaylistInterface::CbInsert\n";
}

void LIRC_PlaylistInterface::CbUpdated(PlayItem &item, unsigned pos)
{
  DEBUG3 << "entering PlaylistInterface::CbUpdated\n";
  ASSERT2(pos < playlist.size());
  playlist[pos] = item;

  if (sessiondata.display)
    sessiondata.display->songUpdated(pos);
  DEBUG3 << "exiting PlaylistInterface::CbUpdated\n";
}

void LIRC_PlaylistInterface::CbRemove(unsigned start, unsigned end)
{
  playlist.erase(playlist.begin()+start-1, playlist.begin()+end);

  if (sessiondata.display)
    sessiondata.display->songsRemoved(int(start)-1);
}

void LIRC_PlaylistInterface::CbClear()
{
  playlist.clear();
  if (sessiondata.display)
    sessiondata.display->playlistCleared();
}
